<?php 
class Attachment_Model extends Model{
	function __construct(){
		parent::__construct();
	}
	function updateMemberIntegral($integral,$rmb,$memberid){
		return $this->db->where("user_id",$memberid)->update("member",array("integral"=>$integral,"rmb"=>$rmb));
	}
	function addDownNote($note){
		return $this->db->insert("downnote",$note);
	}
	function downNote($note){
		return $this->db->getwhere("downnote",$note);
	}
}